==> epythet-0.0.21.tar.gz: epythet-0.0.21/epythet/docs_gen/__init__.py <==
"""Setup and generate Sphinx docs effortlessly

Quickstart
----------

Setup Sphinx docsrc
::

    from epythet.docs_gen.setup_docsrc import make_docsrc
    make_docsrc(PROJECT_DIR)

Generate module docs
::

    from epythet.docs_gen.autogen import make_autodocs
    make_autodocs(PROJECT_DIR)

Compile docs
::

    cd PROJECT_DIR/docsrc
    make html

View by opening ``PROJECT_DIR/docsrc/_build/html/index.html``

Github Pages
------------

Go to your repo settings and set GitHub Pages site to build from the ``/docs`` folder in the ``master`` branch.
Github will tell you where it will be published.
In this case, the site is published at https://i2mint.github.io/epythet/

Compile docs for github
::

    cd PROJECT_DIR/docsrc
    make github

Push generated ``PROJECT_DIR/docs`` to ``master`` branch

Editing and Customizing Docs
----------------------------

You can add RST documentation directly in the source files.
`This source file for example <https://github.com/i2mint/epythet/blob/master/epythet/docs_gen/__init__.py>`_.
"""

from pathlib import Path

_STATIC_FILES = Path(__file__).absolute().parent / '_static'

from epythet.docs_gen.autogen import make_autodocs
from epythet.docs_gen.setup_docsrc import make_docsrc
from epythet.docs_gen.call_make import make


argh_kwargs = {
    'namespace': 'docs_gen',
    'functions': [make_docsrc, make_autodocs, make,],
    'namespace_kwargs': {
        'title': 'Documentation Generator',
        'description': 'Setup and generate Sphinx docs effortlessly',
    },
}

if __name__ == '__main__':
    import argh  # pip install argh

    argh.dispatch_commands(argh_kwargs.get('functions', None))

==> epythet-0.0.27.tar.gz: epythet-0.0.27/epythet/docs_gen/__init__.py <==
"""Setup and generate Sphinx docs effortlessly

Quickstart
----------
As easy as 1, 2, 3

1. Setup Sphinx docsrc
======================
One time setup to create docsrc folder with Sphinx docs config and makefile.  Commit docsrc into your git repo.

Python::

    from epythet.docs_gen.setup_docsrc import make_docsrc
    make_docsrc(PROJECT_DIR)

Command Line::

    epythet docs_gen make-docsrc PROJECT_DIR

2. Generate module docs
=======================
Generate rst docs for all .py modules in your package.  Use make_autodocs each time there is a new .py file added.
These rst files generated in the docsrc folder should also be commited into your git repo.

Python::

    from epythet.docs_gen.autogen import make_autodocs
    make_autodocs(PROJECT_DIR)

Command Line::

    epythet docs_gen make-autodocs PROJECT_DIR

3. Compile docs
===============
Compile generated rst docs with Sphinx makefile.  Use this each time you make changes to your .py files or .rst files.

Python::

    from epythet.docs_gen.call_make import make
    make_autodocs(PROJECT_DIR, 'html')

Command Line::

    epythet docs_gen make PROJECT_DIR html

View by opening ``PROJECT_DIR/docsrc/_build/html/index.html``

Github Pages
------------

Go to your repo settings and set GitHub Pages site to build from the ``/docs`` folder in the ``master`` branch.
Github will tell you where it will be published.
In this case, the site is published at https://i2mint.github.io/epythet/

Compile docs for github
::

    cd PROJECT_DIR/docsrc
    make github

Push generated ``PROJECT_DIR/docs`` to ``master`` branch

Editing and Customizing Docs
----------------------------

You can add RST documentation directly in the source files.
`This source file for example <https://github.com/i2mint/epythet/blob/master/epythet/docs_gen/__init__.py>`_.
"""

from pathlib import Path

_STATIC_FILES = Path(__file__).absolute().parent / '_static'

from epythet.docs_gen.autogen import make_autodocs
from epythet.docs_gen.setup_docsrc import make_docsrc
from epythet.docs_gen.call_make import make


argh_kwargs = {
    'namespace': 'docs_gen',
    'functions': [make_docsrc, make_autodocs, make,],
    'namespace_kwargs': {
        'title': 'Documentation Generator',
        'description': 'Setup and generate Sphinx docs effortlessly',
    },
}

if __name__ == '__main__':
    import argh  # pip install argh

    argh.dispatch_commands(argh_kwargs.get('functions', None))
